From 2ea54a3949abf1d399fd87b09fbc7a059f916897 Mon Sep 17 00:00:00 2001 From: Arnold Moyaux Date: Wed, 1 Feb 2023 13:52:38 +0000 Subject: [PATCH] [FIX] stock: replenish avoid to compute everything Some people create a lot of references but don't use them in their stock. To avoid a big computation time to know the quantities for each product in each location, we only compute it for product having `stock.move` For a database with 60 000 `product.product` and 6 replenish locations but with 100 `stock.move` it goes from 50s to 0.5s opw-3144094 closes odoo/odoo#111628 X-original-commit: 95ddf47a1ca105d9de8fec01c69fbe53b720bfe2 Signed-off-by: William Henrotin (whe) Signed-off-by: Arnold Moyaux (arm) --- addons/stock/models/stock_orderpoint.py | 2 +- 1 file changed, 1 insertion(+), 1 deletion(-) diff --git a/addons/stock/models/stock_orderpoint.py b/addons/stock/models/stock_orderpoint.py index f03fe29e41c..e417836a611 100644 --- a/addons/stock/models/stock_orderpoint.py +++ b/addons/stock/models/stock_orderpoint.py @@ -571,4 +571,4 @@ class StockWarehouseOrderpoint(models.Model): return datetime.combine(self.lead_days_date, time.min) def _get_orderpoint_products(self): - return self.env['product.product'].search([('type', '=', 'product')]) + return self.env['product.product'].search([('type', '=', 'product'), ('stock_move_ids', '!=', False)])